/** @file   RFID_hardware.c
 *  @brief  Hardware initialization for RFID Host
 *  @author LR
 *  @date   Feb 2011
 *  @note   History:
 *          Date        Author      Comment
 *          02/2011     LR          File created and added to GIT
 *  Built with IAR Embedded Workbench Version: 5.20
 *
 */
/* --COPYRIGHT--,BSD
 * Copyright (c) 2011, Texas Instruments Incorporated
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * *  Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * *  Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * *  Neither the name of Texas Instruments Incorporated nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * --/COPYRIGHT--*/

#include <stdint.h>

#include "RFID_hardware.h"

/*id RFID_Hardware_Init(void)
{
    // MOD pin as Output
    P2OUT &= ~BIT0;
    P2DIR |= BIT0;
    // IRQ, SYS_CLK, ASK/OOK as inputs
    P2DIR &= ~(BIT1 | BIT6 | BIT2);
}*/

//===============================================================
// NAME: void Msp430f23x0DileyMillisecond (u08_t n_ms)
//
// BRIEF: Is used to create delays.
//
// INPUTS:
//	Parameters:
//		u08_t		n_ms		delay time in ms
//	
// OUTPUTS:
//
// PROCESS:	[1] do loop of 1 ms duration as often as required
//
// CHANGE:
// DATE  		WHO	DETAIL
// 23Nov2010	RP	Original Code
//===============================================================

void
Msp430f23x0DelayMillisecond(uint32_t n_ms)
{
    while (n_ms--)
    {	
    	__delay_cycles(DELAY_1ms);      // clock speed in Hz divided by 1000
    }
}

//===============================================================
// NAME: void Msp430f23x0CounterSet (void)
//
// BRIEF: Is used to set the timerA.
//
// INPUTS:
//	
// OUTPUTS:
//
// PROCESS:	[1] set timerA
//
// CHANGE:
// DATE  		WHO	DETAIL
// 23Nov2010	RP	Original Code
//===============================================================

void
Msp430f23x0CounterSet(void)
{
	TACTL |= TACLR;
	TACTL &= ~TACLR;				// reset the timerA
	TACTL |= TASSEL0 + ID1 + ID0;	// ACLK, div 8, interrupt enable, timer stoped
	
	TAR = 0x0000;
	TACCTL0 |= CCIE;				// compare interrupt enable
}

//===============================================================
// NAME: void Msp430f23x0OscSel (u08_t mode)
//
// BRIEF: Is used to select the oscilator.
//
// INPUTS:
//	Parameters:
//		u08_t		mode		crystal oscillator or DCO for
//						main clock
//	
// OUTPUTS:
//
// PROCESS:	[1] select the oscilator
//
// CHANGE:
// DATE  		WHO	DETAIL
// 23Nov2010	RP	Original Code
//===============================================================

void
Msp430f23x0OscSel(uint8_t mode)
{

  	uint8_t ii1 = 0;

  	if (mode == 0x00) 				// select crystal oscilator
    {	
    	BCSCTL1 |= XTS + XT2OFF;             		// ACLK = LFXT1 HF XTAL
        BCSCTL3 |= LFXT1S1;                       	// 3  16MHz crystal or resonator
        // the TRF796x sys_clk pin works as ocillator
        // it is set to 6.78 MHz (= 13.56 MHz / 2) in Trf797xInitialSettings()
		// turn external oscillator on
    	do
    	{
      		IFG1 &= ~OFIFG;                   		// Clear OSCFault flag
      		for (ii1 = 0xFF; ii1 > 0; ii1--) 		// Time delay for flag to set
      		{
      		}
    	} while ((IFG1 & OFIFG) == OFIFG);    		// OSCFault flag still set?
    	
    	BCSCTL2 |= SELM1 + SELM0 + SELS;    		// MCLK = SMCLK = HF LFXT1 (safe)

    	return;
    }

  	else                           			//select DCO for main clock
    {	
    	DCOCTL |= DCO0 + DCO1 + DCO2;
    	BCSCTL1 |= XT2OFF + XTS + RSEL0 + RSEL1 + RSEL2;

    	BCSCTL2 &= ~(SELM1 + SELM0 + SELS + DCOR);

    	return;
    }
    						            //_BIC_SR(OSCOFF);
}
