/** @file   RFID_hardware.h
 *  @brief  header file for hardware initialization of RFID Host
 *  @author LR
 *  @date   Feb 2011
 *  @note   History:
 *          Date        Author      Comment
 *          02/2011     LR          File created and added to GIT
 *  Built with IAR Embedded Workbench Version: 5.20
 *
 */
/* --COPYRIGHT--,BSD
 * Copyright (c) 2011, Texas Instruments Incorporated
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * *  Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * *  Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * *  Neither the name of Texas Instruments Incorporated nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * --/COPYRIGHT--*/


//
// Header files
//#include <MSP430x23x0.h> 	
#include <stdint.h>
#include "SPI.h"

#ifndef __HARDWARE_H
#define __HARDWARE_H


//
// Macro definitions
//
/*! Use a  TRF7970 with the corresponding SPI polarity */
#define USE_TRF7970
/*! Default NFC ID for this device */
#define TARGET_CID {0x01, 0xFE, 0x88, 0x77, 0x66, 0x55, 0x44, 0x33, 0x22, 0x11}

// Define Clocks
/*! Mhz   */
#define MHZ         10000
/*! khz   */
#define KHZ         10

/*! SMCLK/MCLK frequency   6.78 MHz*/ 
#define SYS_CLK         (678*MHZ)
/*! XT1/ACLK frequency   */
#define XTAL_CLK        (32768)

/*! Software delay in Miliseconds */
#define DELAY_MS(x)     {__delay_cycles((SYS_CLK/1000)*x);}

#define ENABLE_INTERRUPTS _EINT()
#define TRIGGER		0	     // if TRIGGER 1 trigger-point at LED 5

//EN pin on the TRF796x - P1.0
#define TRF_ENABLEBIT           BIT0
#define TRF_ENABLESET           P1DIR |= TRF_ENABLEBIT
#define TRF_ENABLE              P1OUT |= TRF_ENABLEBIT
#define TRF_DISABLE             P1OUT &= ~TRF_ENABLEBIT

#define MOD_SET			P2DIR |= BIT0;
#define MOD_ON			P2OUT |= BIT0
#define MOD_OFF			P2OUT &= ~BIT0;

// SPI pins in MSP430 (P3.1-P3.3 in 5438, P3.0-P3.2 in 5529)
#define SPI_PSEL                P3SEL
#define SPI_DIR                 P3DIR
#define SPI_OUT                 P3OUT
#define SPI_IN                  P3IN
#define SPI_MOSI_PIN            BIT1
#define SPI_MISO_PIN            BIT2
#define SPI_CLK_PIN             BIT3
// SPI_SS pin in MSP430 (P3.0)
#define SPI_SS_PSEL             P3SEL               //PortSelect
#define SPI_SS_DIR              P3DIR               //Direction
#define SPI_SS_OUT              P3OUT               //Output
#define SPI_SS_IN               P3IN                //Input
#define SPI_SS_PIN              BIT0                //Bit0
#define SLAVESELECT_OUTPUT      SPI_SS_DIR |= SPI_SS_PIN;
#define SLAVESELECT_HIGH        SPI_SS_OUT |= SPI_SS_PIN;
#define SLAVESELECT_LOW         SPI_SS_OUT &= ~SPI_SS_PIN;

//USCI Register for SPI communication with TRF - uses USCI_B0
#define  UCSPICTL0              UCB0CTL0
#define  UCSPICTL1              UCB0CTL1
#define  UCSPIRXBUF             UCB0RXBUF
#define  UCSPITXBUF             UCB0TXBUF
#define  UCSPIIFG               IFG2
#define  UCSPISTAT              UCB0STAT

// IRQ pin definition (P2.1)
#define IRQ_PIN                 BIT1              //Pin 1 
#define IRQ_PIN_SET             P2DIR &= ~IRQ_PIN//Pin 2.1 als Eingang setzen
#define IRQ_PORT                P2IN              //Port 2 als Eingnag
#define IRQ_IS_SET              P2IN & IRQ_PIN    //Abfrage ob Pin1 Port2 == 1
#define IRQ_ON			P2IE |= BIT1	    //IRQ on P2.1 enablen
#define IRQ_OFF			P2IE &= ~BIT1	    //IRQ on P2.1 enablen
#define IRQ_EDGE_SET	        P2IES &= ~BIT1   // rising edge interrupt

// OOK pin control (P2.2)
#define OOK_DIR_IN               P2DIR &= ~BIT2; //Pin 2.2 als Eingang schalten
#define OOK_DIR_OUT	         P2DIR |= BIT2
#define OOK_OFF			 P2OUT &= ~BIT2
#define OOK_ON		         P2OUT |= BIT2

#define LED_PORT_SET	P1DIR |= 0xFC;
#define LED_ALL_OFF     P1OUT &= ~0xFC;
#define LED_ALL_ON	P1OUT |= 0xFC;
#define LED_POWER_ON	P1OUT |= BIT7;
#define LED_POWER_OFF	P1OUT &= ~BIT7;
#define LED_14443A_ON	P1OUT |= BIT6;
#define LED_14443A_OFF	P1OUT &= ~BIT6;
#define LED_14443B_ON	P1OUT |= BIT5;
#define LED_14443B_OFF	P1OUT &= ~BIT5;
#define LED_15693_ON	P1OUT |= BIT4;
#define LED_15693_OFF	P1OUT &= ~BIT4;
#define LED_OPEN1_ON	P1OUT |= BIT3;
#define LED_OPEN1_OFF	P1OUT &= ~BIT3;
#define LED_OPEN2_ON 	P1OUT |= BIT2;
#define LED_OPEN2_OFF 	P1OUT &= ~BIT2; 

//-----Counter-timer constants-----------------------------------
#define COUNT_VALUE	TACCR0					//counter register
// #define START_COUNTER	TACTL |= MC0 + MC1	//start counter in up/down mode
#define START_COUNTER	TACTL |=  MC1		//start counter in up mode

#define STOP_COUNTER	TACTL &= ~(MC0 + MC1)	//stops the counter

//---------------------------------------------------------------

#define COUNT_1ms		847
#define COUNT_60ms		0xC684

//---------------------------------------------------------------

#define DELAY_1ms		6780          //Takte pro ms

//===============================================================

void Msp430f23x0DelayMillisecond(uint32_t n_ms);
void Msp430f23x0OscSel(uint8_t mode);
void Msp430f23x0CounterSet(void);

// Function prototypes
void RFID_Hardware_Init(void);

#endif //__HARDWARE_H
