/****************************************************************
* FILENAME: host.c
*
* BRIEF: Contains functions to interpret the data received from
* host send, appropriate commands to the TRF796x and return the
* response to host.
*
* Copyright (C) 2010 Texas Instruments, Inc.
*
* AUTHOR(S): Reiser Peter		DATE: 02 DEC 2010
*
* EDITED BY: Josh Wyatt
* *
*
****************************************************************/

#include "host.h"
#include "nfc.h"
//===============================================================

char* const revision = "Firmware Revision 07_27_2011\r\n\0";

//===============================================================

#if TRIGGER
	u08_t trigger = 0;
#endif

uint8_t	first_spi_data = 1;
extern uint8_t buffer[BUF_LENGTH];
//extern u08_t rx_error_flag;
//extern s08_t rxtx_state;
extern uint8_t irq_flag;
extern uint8_t stand_alone_flag;
extern uint8_t enable;
extern uint8_t i_reg;
extern uint8_t reader_mode;

#ifdef ENABLE15693
	extern u08_t	afi;
	extern u08_t	flags;
#endif

//===============================================================

//uint8_t HostRequestCommand(u08_t *pbuf, u08_t length, u08_t broken_bits, u08_t no_crc);
//uint8_t HostRequest14443A(u08_t *pbuf, u08_t length, u08_t BitRate);

//===============================================================
// NAME: void HostCommands(void)
//
// BRIEF: Interprets the data received from host, initiates
// execution of right commands and return response to host.
//
// INPUTS:
//	Globals:
//		u08_t		buffer[300]	contains received data from host
// OUTPUTS:
//	Globals:
//		u08_t		buffer[300]	values for command execution
//
// PROCESS:	[1] get data from host
//			[2] interpret data
//			[3] start execution
//
// NOTE: Response for all unknown commands is unknown command.
//
// CHANGE:
// DATE  		WHO	DETAIL
// 18 Nov 2010	RP	Original Code
//===============================================================

void
HostCommands(void)
{
	char *phello;
	uint8_t i = 0;
	uint8_t *pbuf, count = 0;
       
	
	//STOP_COUNTER;

	if (stand_alone_flag == 0)
	{	
		pbuf = &buffer[0];
		#if TRIGGER
			if(trigger != 0)
			{	for(i = 0; i < 50; i++)
				{	*(pbuf + i) = *(pbuf + i + 250);
				}
			}
			else
			{
				UartGetLine(pbuf);
				if(trigger != 0)
				{	for(i = 0; i < 50; i++)
					{	*(pbuf + i + 250) = *(pbuf + i);
					}
				}
				trigger = 0;
			}
		#else
			UartGetLine(pbuf);
		#endif
	}
	stand_alone_flag = 0;
	UartPutCrlf();  // finish line

	pbuf = &buffer[4];
	
	switch(*pbuf)
	{
		case 0xFF:   // check COM port number
			phello = "TRF7970A EVM \r\n";
			UartSendCString(phello);
			break;
		
		case 0x10: // register write (adress:data, adress:data, ...)
			phello = "Register write request.\r\n";
			UartSendCString(phello); 
			pbuf = &buffer[6];
                        RADIO_WRITESINGLE(buffer[5],pbuf);
			for(i = 5; count > 0; i = i + 2)
			{
				if(buffer[i] == ISOControl)
				{
			          RADIO_WRITESINGLE(ISOControl, &buffer[i + 1]);
				}
				count--;
				count--;
			}
			break;
			
		case 0x11:  // continuous write (adress:data, data, ...)
			phello = "Continous write request.\r\n";
			UartSendCString(phello);
			count = buffer[0] - 8;
                        pbuf = &buffer[6];
                        RADIO_WRITECONT(buffer[5], pbuf, count-1);
			break;
			
		case 0x12:  // register read (adress:data, adress:data, ...
			phello = "Register read request.\r\n";
			UartSendCString(phello);
                        pbuf = &buffer[6];
                        RADIO_READSINGLE(buffer[5], pbuf);
			UartResponse(&buffer[5], count);
			break;
			
		case 0x13:							//continuous read (adress:data, data, ...)
			phello = "Continous read request\r\n";
			UartSendCString(phello);
			pbuf = &buffer[4];
                        pbuf++;
			count = *pbuf;					// the amount of registers to be read
	
			// is specified after the command
			pbuf++;
			buffer[5] = *pbuf;					// the start register is specified
	
			// after the amount of registers
                        pbuf = &buffer[5];
			RADIO_READCONT(buffer[5], pbuf, count); 
			UartResponse(&buffer[5], count);
			break;
			

		case 0x15:
			phello = "Direct command.\r\n";
			UartSendCString(phello);
                        pbuf = &buffer[5];
			RADIO_DIRECTCOMMAND(buffer[5], pbuf);
			break;
			
		case 0x16:  // raw
			phello = "RAW mode.\r\n";
			UartSendCString(phello);
			count = buffer[0] - 8;
                        pbuf = &buffer[6];
                        RADIO_WRITERAW(buffer[5], pbuf, count);
			break;
			
		case 0x03: // enable or disable the reader chip
			switch(*(pbuf + 1))
			{
				case 0xFF:	
					McuOscSel(*(pbuf + 1));
					TRF_DISABLE;
					UartSendCString("Reader disabled.");
					enable = 0;
					break;
					
				case 0x00:
					McuOscSel(*(pbuf + 1));
					TRF_ENABLE;
					UartSendCString("Reader enabled.");
					enable = 1;
					break;	
			}
			break;
			
		case 0xF0:							// AGC toggle
			buffer[0] = ChipStateControl;
			buffer[1] = ChipStateControl;
                        pbuf = &buffer[1];
			RADIO_READSINGLE(buffer[1], pbuf);
			if(*pbuf == 0xFF)
			{	
				buffer[1] |= BIT2;
			}
			else
			{	
				buffer[1] &= ~BIT2;
			}
                        RADIO_WRITESINGLE(buffer[0],&buffer[1]);
			break;
			
		case 0xF1:							// AM PM toggle
			buffer[0] = ChipStateControl;
			buffer[1] = ChipStateControl;
                        pbuf = &buffer[1];
			RADIO_READSINGLE(buffer[1], pbuf);
			if((*pbuf) == 0xFF)
			{	
				buffer[1] &= ~BIT3;
			}
			else
			{	
				buffer[1] |= BIT3;
			}
			RADIO_WRITESINGLE(buffer[0],&buffer[1]);
			break;
			
		case 0xF2:							// Full - half power selection (FF - full power)
			buffer[0] = ChipStateControl;
			buffer[1] = ChipStateControl;
			pbuf = &buffer[1];
			RADIO_READSINGLE(buffer[1], pbuf);
			if((*pbuf) == 0xFF)
			{	
				buffer[1] &= ~BIT4;
			}
			else
			{	
				buffer[1] |= BIT4;
			}
			RADIO_WRITESINGLE(buffer[0],&buffer[1]);
			break;
			
		case 0xFE:							// Firmware Version Number	
			UartSendCString(revision);
			break;
			
		case 0xF3:							// LED open on
			LED_OPEN2_ON;
			break;
			
		case 0xF4:							// LED open off
			LED_OPEN2_OFF;
			break;
			
		case 0xF5:							// LED TAG-IT on
			LED_OPEN1_ON;
			break;
			
		case 0xF6:							// LED TAG-IT off
			LED_OPEN1_OFF;
			break;
			
		case 0xF7:							// LED ISO15693 on
			LED_15693_ON;
			break;
			
		case 0xF8:							// LED ISO15693 off
			LED_15693_OFF;
			break;
		
		case 0xF9:							// LED typeB on
			LED_14443B_ON;
			break;
			
		case 0xFA:							// LED typeB off
			LED_14443B_OFF;
			break;
			
		case 0xFB:							// LED typeA on
			LED_14443A_ON;
			break;
			
		case 0xFC:							// LED typeA off
			LED_14443A_OFF;
			break;	
	    default:
			phello = "Unknown command.\r\n";
			UartSendCString(phello);
			break;
	}										// switch
        ResetDecoders(); //Decoder Reseten
        RADIO_READCONT(IRQStatus,buffer,2); //IRQStatus (0x0C)	
	while(!(IFG2 & UCA0TXIFG))						// till UART Transmit buffer is empty
	{
	}
	reader_mode = 0x00;
}	// HostCommands

