/*
 * main.c
 */
#include <stdint.h>
#include <stdio.h>
#include <stdlib.h>
#include <MSP430x23x0.h> 	
#include "NFC/RFID_hardware.h"
#include "NFC/nfc.h"
#include "NFC/rfid_hal.h"
#include "NFC/Android_P2P.h"
#include "NFC/types.h"
#include "NFC/uart.h"
#include "NFC/mcu.h"
#include "NFC/host.h"

uint8_t enable = 0;
//uint8_t first_spi_data = 1; //in Host schreiben
uint8_t i_reg;
uint8_t irq_flag;
uint8_t remote_flag = 0;
uint8_t stand_alone_flag;
uint8_t reader_mode = 0x00;   // determines how interrupts will be handled

uint8_t buffer[BUF_LENGTH];

uint16_t timeoutCounter;
uint8_t messageDirection = 0;

uint8_t trigger=1;
uint8_t messageNr=0;

char *phello;

void setMessage(char* text);
void rxMenu(void);
void txMenu(void);

void main(void)
{
        uint16_t count = 0;
        
        // Stop WDT
	WDTCTL = WDTPW + WDTHOLD;
        
        #ifdef ENABLE_HOST
        UartSetup(); // settings for UART
        #endif
	
	// Initialize Radio
	TRF_ENABLESET;
	TRF_ENABLE;
        
        McuDelayMillisecond(1);
	
	// Configure IRQ pin
        TRF_ENABLESET;
	IRQ_PIN_SET;
        IRQ_EDGE_SET;	

	// Setup SPI to communicate with TRF7970A
	USCISPIset();     // Set the USCI - SPI Mode for TRF communication 
        
        LED_ALL_OFF;
	LED_PORT_SET;
        
        // Initialize Radio settings
	Radio_InitialSettings();
        
        McuOscSel(0x00);       		  // set the oscillator
	McuDelayMillisecond(10);
	
	// Re-configure the USART with this external clock
        USCISPIset();

	// Initialize TRF7970A for NFC communications
	NFC_Init();
	message[0] = 0;
        
        // Globally enable interrupts
	ENABLE_INTERRUPTS;
        
        LED_ALL_OFF;
        
        LED_PORT_SET;
  
        LED_POWER_ON;   //Power LED leuchtet
        
        OOK_DIR_IN; 
        enable = 1;    // indicates, that setting are done
        
        reader_mode = 0x00;
	stand_alone_flag = 1;				// stand alone mode
	remote_flag = 0;				// host is not activ
        
         for(count = 0; count <= 5000; count++)
        {
          McuDelayMillisecond(1);
        }
        
        phello = "PowerOn\r\n";
        UartSendCString(phello);
       
        phello = "NFC-P2P Demo\r\n";
        UartSendCString(phello);
        phello = "First-rxMenu\r\n";
	UartSendCString(phello);
        
        
        if(trigger)
	{
		txMenu();
	}
	else
	{
		rxMenu();
	}

	// Main loop
	while (1)
	{
		if(remote_flag == 1) 
                {
                  #ifdef ENABLE_HOST
                  buffer[4] = 0xff;			// "TRF7960 EVM" message in GUI
		  HostCommands();			// device works according host commands
                  #endif 
                }
                else
                {
                    messageStatus = 0;
		    NFCTarget_statemachine(); //Run the state machine for NFC P2P communication
		    if(messageStatus == MESSAGE_RECEIVED)
		    {
			//show what we received
                  
                        phello = "Received Message:";
                        UartSendCString(phello);
                        phello = message;
	                UartSendCString(phello);
                        
			//while(!buttonsPressed);
			if(trigger) //TX Menu
			{
			  txMenu();
			}
			else //RX data
			{
			  rxMenu();
			}
		    }
		    else if(messageStatus == MESSAGE_SENT)
		    {
			//show what we sent

			phello = "Message Sent:";
                        UartSendCString(phello);
                        phello = message;
	                UartSendCString(phello);
                  
                  
                        //while(!buttonsPressed);
			if(trigger) //TX Menu
			{
			  txMenu();
			}
			else //RX data
			{
			  rxMenu();
			}
		   }
               }   
        }
}

void txMenu(void)
{
	/*buttonsPressed = 0;
	Dogs102x6_clearScreen();
	Dogs102x6_stringDraw(7, 0, "   *S1=Select*   ", DOGS102x6_DRAW_NORMAL);*/
	
        switch (messageNr)
	{
	  case 1: setMessage("Hello Android."); break;
	  case 2: setMessage("MSP430F5529"); break;
	  case 3: setMessage("TRF7970A"); break;
	  case 4: setMessage("NFC P2P Demo"); break;
	  case 5: setMessage("What's up?"); break;
	  case 6: setMessage(":-)"); break;
	  default: break;
	}
       
        messageNr++;
        
        if (messageNr == 7)
            messageNr = 1;
        
	//buttonsPressed = 0;
	/*Dogs102x6_clearScreen();
	Dogs102x6_stringDraw(3, 0, "Tap phone to TX: ", DOGS102x6_DRAW_NORMAL);
	Dogs102x6_stringDraw(4, 0, message+1, DOGS102x6_DRAW_NORMAL);*/
	messageDirection = SENDING;
        trigger = 0;
}

void rxMenu(void)
{
	/*buttonsPressed = 0;
	Dogs102x6_clearScreen();
	Dogs102x6_stringDraw(3, 0, "Tap phone to RX", DOGS102x6_DRAW_NORMAL);*/
	messageDirection = RECEIVING;
        trigger = 1;
}

void setMessage(char* text)
{
	//Store the message to send. Message[0] stores the message length.
	uint8_t i = 0;
	do
	{
		message[i+1] = text[i];
		i++;
	}
	while(text[i] != 0);
	message[i+1] = 0; //end line character
	message[0] = i; //store the length
}
